BasicCleaner class
Main class to clean text using modular filters.
Constructors
- BasicCleaner({CleanConfig? config})
Properties
- config → CleanConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clean(
String input) → String - Cleans the given text by applying selected filters.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited