CleanConfig class

Configuration for text cleaning behavior.

Constructors

CleanConfig({bool toLowerCase = true, bool removeNumbers = true, bool removePunctuation = true, bool removeExtraSpaces = true, bool removeStopwords = false, bool removeSpecialChars = true, bool removeHtml = true, bool removeUrls = true, bool removeEmails = true, bool removeEmojis = false, String language = 'en', List<String Function(String)>? customFilters})
const

Properties

customFilters List<String Function(String)>?
final
hashCode int
The hash code for this object.
no setterinherited
language String
final
removeEmails bool
final
removeEmojis bool
final
removeExtraSpaces bool
final
removeHtml bool
final
removeNumbers bool
final
removePunctuation bool
final
removeSpecialChars bool
final
removeStopwords bool
final
removeUrls bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toLowerCase bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited