TextUtils class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
removeEmails(
String input) → String -
removeEmojis(
String input) → String -
removeExtraSpaces(
String input) → String -
removeHtmlTags(
String input) → String -
removeNumbers(
String input) → String -
removePunctuation(
String input) → String -
removeSpecialCharacters(
String input, {String language = 'en'}) → String -
removeStopwords(
String input, String language) → String -
removeUrls(
String input) → String -
toLowerCaseUnicode(
String input) → String